package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(@``````````0```````
M`+&8``````!``#@`"0!``!H`&0````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*D(````````J0@`
M```````0``````$````&````````J\````````"[P````````+O`````````
M!,@````````$\````````!```````@````8```````"KT````````+O0````
M````N]`````````"``````````(```````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````H@````````"B`````````*(``````````.0`````````Y```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*O`````````N\``````
M``"[P`````````1`````````!$```````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`61!0F1C7V7:5VR_R:&E_?]?^@P`````$````$```
M``%'3E4```````````,````"```````````````1````0@````0````(A`1`
M!0`0$""$`(:`!``"*`@$(`D```F""`(`ND$0@(@`````````0@```$4```!(
M````20```%````!1````4@````````!4````50```%8```!7````6````%H`
M`````````!_?Q6XM1][.?)I_:[:;Q2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C
M2ZR'U_I"+#_EPGR2X[I@;*'[UD,):V;,KV?LU45"TW`'B>W;8C/,)8P5"Y<Z
M#9N<J7\*`J?@4)X::TG[X*,`````````````````````````````````````
M`P``"P```````!C```````````````-9$@``````````````````````````
M``)_$@````````````````````````````",$0``````````````````````
M``````&5$@````````````````````````````'F$@``````````````````
M``````````)F$@````````````````````````````#*$@``````````````
M``````````````(B$@````````````````````````````&<$@``````````
M```````````````````!(`````````````````````````````)?$@``````
M``````````````````````!G$@````````````````````````````"K$@``
M``````````````````````````#3$@````````````````````````````*Q
M$@````````````````````````````&&$@``````````````````````````
M``'6$@````````````````````````````$V$@``````````````````````
M``````%B$@````````````````````````````"4$@``````````````````
M```````````0(`````````````````````````````*7$@``````````````
M``````````````$M$@````````````````````````````"*$0``````````
M``````````````````%$$@`````````````````````````````L(```````
M``````````````````````"=$@````````````````````````````*)$@``
M``````````````````````````%:$@````````````````````````````#N
M%@````````````````````````````$!$@``````````````````````````
M``%_$@````````````````````````````(U$@``````````````````````
M``````$<$@````````````````````````````*B$@``````````````````
M``````````#`$@````````````````````````````!8(@``````````````
M``````````````&I$@````````````````````````````*Z$@``````````
M``````````````````%+$@````````````````````````````&C$@``````
M``````````````````````%J$@````````````````````````````)Q$@``
M``````````````````````````('$@````````````````````````````!Y
M$@````````````````````````````%X$@``````````````````````````
M``'!$@````````````````````````````"<$@``````````````````````
M``````#G$@````````````````````````````'R$@``````````````````
M``````````"S$@````````````````````````````)3$@``````````````
M``````````````*$$@````````````````````````````'/$@``````````
M``````````````````)&$0````````````````````````````&-$@``````
M``````````````````````"D$@````````````````````````````#9$@``
M``````````````````````````$1$@````````````````````````````"X
M$@````````````````````````````(3$@``````````````````````````
M``!&$@````````````````````````````%Q$@``````````````````````
M``````&Z$0````````````````````````````-B$@``#0```````%T@````
M`````-(```.W$@``#0```````%)P````````"&0```!3$@``#0```````!_`
M`````````CH```+9$@``#0```````$5```````````8```+W$@``#0``````
M`%K@`````````CX```/=$@``#0```````$50`````````WH```.=$```%P``
M`````,"(``````````````+J$@``#0```````$C0`````````#0```,-$@``
M#0```````%`0`````````'8```-N$0``#P```````&%@``````````0```.*
M$@``#0```````%Y@`````````30```.5$@``#0```````$0``````````#@`
M``.R$```%P```````,"P``````````````/+$@``#0```````%#`````````
M`:0```-]$```%@```````,````````````````,Q$@``#0```````$D0````
M`````60```/$$```%@```````,"(``````````````/J$0``%@```````,"`
M``````````@```.#$@``#0```````"(```````````````.I$@``#0``````
M`%X``````````%0```-_(```%@```````,````````````````-'$@``#0``
M`````%"0`````````"P```,;$@``#0```````$1``````````/0```,]$@``
M#0```````%^@`````````7(```/T$@``#0```````$J`````````!8P`7U]G
M;6]N7W-T87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?
M<F5G:7-T97)434-L;VYE5&%B;&4`7U]L:6)C7W-T87)T7VUA:6X`7U]C>&%?
M9FEN86QI>F4`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9F%I;`!?
M7V5N=FER;VX`<W1R;F-M<`!L<W1A=#8T`&%C8V5S<P!L<V5E:S8T`')E860`
M;W!E;F1I<@!R96%D9&ER-C0`8VQO<V5D:7(`<FUD:7(`7U]S<')I;G1F7V-H
M:P!U;FQI;FL`4$Q?8W5R<F5N=%]C;VYT97AT`&)O;W1?1'EN84QO861E<@!0
M97)L7VYE=UA3`%!E<FQ?;F5W6%-?9FQA9W,`<F5A9&QI;FL`4&5R;%]S=E]S
M971P=@!M96UC:'(`4&5R;%]S=E]S971P=FX`<F5A;&QO8P!M96UM;W9E`&=E
M='!I9`!M96UC<'D`<W1R8VAR`'-T<F1U<`!S=')T;VL`<W1R<F-H<@!G971U
M:60`<W1R<W1R`&UK9&ER`%]?97)R;F]?;&]C871I;VX`<W1D97)R`%]?9G!R
M:6YT9E]C:&L`;W!E;C8T`%!E<FQ?9W9?9F5T8VAP=@!097)L7V=E=%]S=@!0
M97)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VUG7W-E=`!097)L7W-Y<U]I;FET
M,P!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]A=&9O<FM?;&]C:P!03%]D;U]U
M;F1U;7``4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?<&%R<V4`<&5R;%]D97-T
M<G5C=`!P97)L7V9R964`4&5R;%]S>7-?=&5R;0!P97)L7V%L;&]C`'!E<FQ?
M8V]N<W1R=6-T`'!E<FQ?<G5N`&5X:70`;&EB<&5R;"YS;RXU+C,V`&QI8F,N
M<V\N-@!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA
M;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R
M;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E
M='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R
M=`!S:&%?=7!D871E`'AS7VEN:70`7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N
M9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L:6)P871H`'!A<E]F
M:6YD<')O9P!M>5]P87)?<&P`<&%R7VEN:71?96YV`$=,24)#7S(N,S0`1TQ)
M0D-?,BXT`$=,24)#7S(N,S,`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXR````````
M``(``0`"``(``0`!``(``0`"``$``@`#``(``@`!``(``0`!``(``@`!``$`
M`@`"``(``0`$``$``@`!``$``@`!``$``0`"``(``@`"``$``@`"``$``0`%
M``(`!0`$``(``0`"``$``@`"``$``@`"``4``0`"``$`!@`"``(``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0``
M``$`!0```L\````0``````:6D;0````&```$`0```!`-:6D4````!0``!`P`
M```0!I:1LP````0```06````$`EI&7(````#```$(0```!`-:6D2`````@``
M!"T`````````````N\``````````#````````",@````````N\@`````````
M#````````"+0````````OZ@`````````#````````%K@````````O^@`````
M````#````````,"`````````O_@`````````#````````!_`````````P`@`
M````````#````````,`(````````P"``````````#````````*&J````````
MP"@`````````#````````&&\````````P#@`````````#````````&)<````
M````P$``````````#````````&)@````````P$@`````````#````````*&>
M````````P%``````````#````````&'"````````P%@`````````#```````
M`*&F````````P&@`````````#````````*&.````````P'``````````#```
M`````*&4````````P(``````````#````````&0>````````OY`````$````
M"@``````````````````OY@````)````"@``````````````````OZ`````+
M````"@``````````````````O[`````6````"@``````````````````O[@`
M```;````"@``````````````````O\`````?````.```````````````````
MO\@````@````"@``````````````````O]`````B````"@``````````````
M````O]@````F````"@``````````````````O^`````X````"@``````````
M````````O_````!!````"@``````````````````O>@````"````"P``````
M````````````O?`````#````"P``````````````````O?@````%````"P``
M````````````````O@`````&````"P``````````````````O@@````'````
M"P``````````````````OA`````(````"P``````````````````OA@````*
M````"P``````````````````OB`````,````"P``````````````````OB@`
M```-````"P``````````````````OC`````.````"P``````````````````
MOC@````/````"P``````````````````OD`````0````"P``````````````
M````OD@````1````"P``````````````````OE`````2````"P``````````
M````````OE@````3````"P``````````````````OF`````4````"P``````
M````````````OF@````5````"P``````````````````OG`````7````"P``
M````````````````OG@````8````"P``````````````````OH`````:````
M"P``````````````````OH@````<````"P``````````````````OI`````=
M````"P``````````````````OI@````>````"P``````````````````OJ``
M```A````"P``````````````````OJ@````C````"P``````````````````
MOK`````D````"P``````````````````OK@````E````"P``````````````
M````OL`````F````"P``````````````````OL@````G````"P``````````
M````````OM`````H````"P``````````````````OM@````I````"P``````
M````````````ON`````J````"P``````````````````ON@````K````"P``
M````````````````OO`````L````"P``````````````````OO@````M````
M"P``````````````````OP`````N````"P``````````````````OP@````O
M````"P``````````````````OQ`````P````"P``````````````````OQ@`
M```Q````"P``````````````````OR`````R````"P``````````````````
MOR@````S````"P``````````````````OS`````T````"P``````````````
M````OS@````U````"P``````````````````OT`````V````"P``````````
M````````OT@````W````"P``````````````````OU`````Y````"P``````
M````````````OU@````Z````"P``````````````````OV`````[````"P``
M````````````````OV@````\````"P``````````````````OW`````]````
M"P``````````````````OW@````^````"P``````````````````OX`````_
M````"P``````````````````OX@```!`````"P``````````ZV_P,``DN00`
M'Z?[_V#C$/```"3`P```4G[`$```4V/C$!````2Y`@`1IX0``PWAXT#Q$``$
MZV_PT``$!_0'!^,0\#@`),`0``!29=('\#`0".,0$!``!`?Q!P`'``<`P!``
M`%)DXQ`0```$!_$-$.,0$`P`%,#T____Y0````#`$```4ECC$!````0'\0T0
MXQ`0#``4P/3____5````&,`0``!23.,0$```!`?Q#1#C$!`,`!3`]/___\4`
M```PP!```%)`XQ`0```$!_$-$.,0$`P`%,#T____M0```$C`$```4C3C$!``
M``0'\0T0XQ`0#``4P/3___^E````8,`0``!2*.,0$```!`?Q#1#C$!`,`!3`
M]/___Y4```!XP!```%(<XQ`0```$!_$-$.,0$`P`%,#T____A0```)#`$```
M4A#C$!````0'\0T0XQ`0#``4P/3___]U````J,`0``!2!.,0$```!`?Q#1#C
M$!`,`!3`]/___V4```#`P!```%'XXQ`0```$!_$-$.,0$`P`%,#T____50``
M`-C`$```4>SC$!````0'\0T0XQ`0#``4P/3___]%````\,`0``!1X.,0$```
M!`?Q#1#C$!`,`!3`]/___S4```$(P!```%'4XQ`0```$!_$-$.,0$`P`%,#T
M____)0```2#`$```4<CC$!````0'\0T0XQ`0#``4P/3___\5```!.,`0``!1
MO.,0$```!`?Q#1#C$!`,`!3`]/___P4```%0P!```%&PXQ`0```$!_$-$.,0
M$`P`%,#T___^]0```6C`$```4:3C$!````0'\0T0XQ`0#``4P/3___[E```!
M@,`0``!1F.,0$```!`?Q#1#C$!`,`!3`]/___M4```&8P!```%&,XQ`0```$
M!_$-$.,0$`P`%,#T___^Q0```;#`$```48#C$!````0'\0T0XQ`0#``4P/3_
M__ZU```!R,`0``!1=.,0$```!`?Q#1#C$!`,`!3`]/___J4```'@P!```%%H
MXQ`0```$!_$-$.,0$`P`%,#T___^E0```?C`$```45SC$!````0'\0T0XQ`0
M#``4P/3___Z%```"$,`0``!14.,0$```!`?Q#1#C$!`,`!3`]/___G4```(H
MP!```%%$XQ`0```$!_$-$.,0$`P`%,#T___^90```D#`$```43CC$!````0'
M\0T0XQ`0#``4P/3___Y5```"6,`0``!1+.,0$```!`?Q#1#C$!`,`!3`]/__
M_D4```)PP!```%$@XQ`0```$!_$-$.,0$`P`%,#T___^-0```HC`$```413C
M$!````0'\0T0XQ`0#``4P/3___XE```"H,`0``!1".,0$```!`?Q#1#C$!`,
M`!3`]/___A4```*XP!```%#\XQ`0```$!_$-$.,0$`P`%,#T___^!0```M#`
M$```4/#C$!````0'\0T0XQ`0#``4P/3___WU```"Z,`0``!0Y.,0$```!`?Q
M#1#C$!`,`!3`]/___>4```,`P!```%#8XQ`0```$!_$-$.,0$`P`%,#T___]
MU0```QC`$```4,SC$!````0'\0T0XQ`0#``4P/3___W%```#,,`0``!0P.,0
M$```!`?Q#1#C$!`,`!3`]/___;4```-(P!```%"TXQ`0```$!_$-$.,0$`P`
M%,#T___]I0```V#`$```4*CC$!````0'\0T0XQ`0#``4P/3___V5```#>,`0
M``!0G.,0$```!`?Q#1#C$!`,`!3`]/___84```.0P!```%"0XQ`0```$!_$-
M$.,0$`P`%,#T___]=0```ZC`$```4(3C$!````0'\0T0XQ`0#``4P/3___UE
M```#P,`0``!0>.,0$```!`?Q#1#C$!`,`!3`]/___54```/8P!```%!LXQ`0
M```$!_$-$.,0$`P`%,#T___]10```_#`$```4&#C$!````0'\0T0XQ`0#``4
MP/3___TU```$",`0``!05.,0$```!`?Q#1#C$!`,`!3`]/___24```0@P!``
M`%!(XQ`0```$!_$-$.,0$`P`%,#T___]%0``!#C`$```4#SC$!````0'\0T0
MXQ`0#``4P/3___T%```$4,`0``!0,.,0$```!`?Q#1#C$!`,`!3`]/___/4`
M``1HP!```%`DXQ`0```$!_$-$.,0$`P`%,#T___\Y0``!(#`$```4!CC$!``
M``0'\0T0XQ`0#``4P/3___S5```$F,`0``!0#.,0$```!`?Q#1#C$!`,`!3`
M]/___,4```2PP!```%``XQ`0```$!_$-$.,0$`P`%,#T___\M0``!,C`$```
M3_3C$!````0'\0T0XQ`0#``4P/3___RE```$X.MO\#``)+)/`+#C\/\X_W'C
M,/"H`"3C0/"@`"10(/"TZ[L`(``-LD\`L4%`\*#2!_#`L"A!,/"H02#PM,#E
M____LL1(``!/R\0H``!/Y+D$`#3`Y0``((?$&```3^25`!``IX0`H<`0``!/
MS>,0$```!%B@\+3C$;````3L*@`$`-B6`Q1ZN10`(NLB``,`#:>J``/`Y?__
M_P;C,/"H``3`$```4!"Y!`!2Q"L``%`7XR`P```$XQ`0```$XR!0```D6)#P
MM,`@```AR.,04!``).,@4`@`),`@```AP>,@4!@`).R<`)\!?D$P,`BG"``$
M[$G__P#8XR`P```$N10`$.L1``,`#>,A4```)*<*``&G.P`(IT;_\>P9``,`
MV,0H``!/Y+D4`!'K$0`#``U!$5``Y4@0````N10`2J=I``#`,```#Q?`Y?__
M_$P8HNPH`$,`?L0H``!/R4&0\+S`Y?___A"Y!``YP"```"!RP.4```RP["@`
M.0!\Q"@``$^VP.7___O_P.7___T\U0?PP+`HN10`*J=T`$[K;_#X``0'_L#E
M___\[L0K``!/G^PH`#T`?,#E___]9<`0``!/(N,@$```!.,BL```!)(`*B>G
M]/]-Q"@``$^)P.7___QR&**G]/^YP!```$]\XR`0```"IX0`!\#E```=M*?T
M_[^Y!``YP"```!_\P.4```QBQ"L``$]G["C_L@!\I_3_[:<8``2G]/]]IRD`
M`<#E___]:<#E___]Q@<'!P<'!T%`\`CC,/````2G"?_PN8``\*?[_U#7!_``
M\`#K[_"@`"1!</"@IVD``*=9``#`(```3N7C("````3`Y?___J,```<'!P<'
M!P<'!P<'!P<'P!```$\<P"```$\9[!(`"H!DQ!@``$ZG[!@`!`!\!_$'_@<'
M!P<'!P<'!P<'!P<'P"```$\$P!```$\!N0D`$NLA``,`"NLQ`#\`#+D(`#+K
M,P`!``KL.``-`'S$&```3H;L&``'`'S`(```3N@'\0?^!P<'!P<'!P<'!P<'
M!P?KO_!8`"3`L```3MGC\/]@_W&5`+``IW0`%<`0``!.=^,0$````J>$``C$
M*```3H?`Y?___,#`Y?___Z62`;``Z[_P^``$!_X'!P<'!P<'!\#T____L`<'
M!P<'!P<'!P?K;_`P`"2R3P"PX_#\R/]QZ[L`(``-LD\`L>=@#P\`1-('\S"P
M*$&0\+!!4"`XN00`&;D$`#FG20`$YP!0`#`&IUL`$.<@`"`P..<`8```:.="
M```P8><B```P8.=`,``P#N<@,!`P#J<[`""G1__GYP"0,#`&YR"0$#`&XZ"0
M(``$YP#PH#`.XP"0*``$YV`/#P!$ISD`(.=`$$`P!N.`\*``!..0\*@`!.=`
M\*`P#N<`$&@P!N=`$``P!KD$`$KG$/"@,`:Y!`!0N00`J.<!````;><`0```
M;><`(```;><@``$P,.<``!\P..<"````:N<`8```:.<`$(`P#N<D4```8KD$
M``FG&P`0IS?_QN,`(!@`!..`\+@`!.,`\*``).-`(```!.-0(!``!..@(`@`
M!.,P\+``!./0\,``!,**6H)YF;D(`(#".EJ">9G"VEJ">9GC,"`@``BY"`#5
MZVH``@`,[&H`(1Y6[)8@OP!5N>>0%;F``!2Y@@`5N0@`&+GG`(6Y@`"*N8(`
M@.QT(+\E6>QT(#H%5KD(`'/K-``"``RY"`!X[#0`(1Y6[(<@OP!5N8(`8[F`
M`&BY@@!IN0@`;>/0\,@`!.QW.[\E6<+:6H)YF>QX`#H%5KGHD`VY"``7ZY@`
M`@`,['$@OP!5[)@`(1Y6[!$[OR59[!<`.@56N0@`%NQC(+\`5>S1.[\E6;F"
M`#GL@2"_`%6YY'`3N00`/>/0\-``!.PX`#H%5L+:6H)YF;F"`!:Y"``0N>A@
M#;D(`!/L:2"_`%7LT3N_)5GK-P`"``SL-P`A'E:Y@@"3['$@OP!5N>2`&;D$
M`)WCT/#8``3LEP`Z!5;"VEJ">9FY@@`6N0@`$+GH8`VY"``9[&,@OP!5[-$[
MOR59ZY@``@`,[)@`(1Y6N8(`.>R!(+\`5;GD<!.Y!``]X]#PX``$[#@`.@56
MPMI:@GF9N8(`%KD(`!"YZ&`-N0@`$^QI(+\`5>S1.[\E6>LW``(`#.PW`"$>
M5KF"`)/L<2"_`%6YY(`9N00`G>/0\.@`!.R7`#H%5L+:6H)YF;F"`!:Y"``0
MN>A@#;D(`!GL8R"_`%7LT3N_)5GKF``"``SLF``A'E:Y@@`Y[($@OP!5N>1P
M$[D$`#WCT/#P``3L.``Z!5;"VEJ">9FY@@`6N0@`$+GH8`VY"``3[&D@OP!5
M[-$[OR59ZS<``@`,[#<`(1Y6N8(`D^QQ(+\`5;GD@!FY!`"=X]#P^``$[)<`
M.@56PMI:@GF9N8(`%KD(`!"YZ&`-N0@`&>QC(+\`5>S1.[\E6>N8``(`#.R8
M`"$>5KF"`#GL@2"_`%6YY'`3N00`/>/0\0``!.PX`#H%5L+:6H)YF;F"`!:Y
M"``0N>A@#;D(`!/L:2"_`%7LT3N_)5GK-P`"``SL-P`A'E:Y@@"3['$@OP!5
MN>2`&;D$`)WCT/$(``3LEP`Z!5;"VEJ">9FY@@`6N0@`$+GH8`VY"``9[&,@
MOP!5[-$[OR59ZY@``@`,[)@`(1Y6N8(`.>R!(+\`5;GD<!.Y!``]X]#Q$``$
M[#@`.@56PMI:@GF9N8(`%KD(`!"YZ&`-N0@`$^QI(+\`5>S1.[\E6>LW``(`
M#.PW`"$>5KF"`)/L<2"_`%6YY(`9N00`G>/0\1@`!.R7`#H%5L+:6H)YF;F"
M`!:Y"``0N>A@#;D(`!GL8R"_`%7LT3N_)5GKF``"``SLF``A'E:Y@@`Y[($@
MOP!5N>1P$[D$`#WCT/$@``3L.``Z!5;"VEJ">9FY@@`6N0@`$+GH8`VY"``3
M[&D@OP!5[-$[OR59ZS<``@`,[#<`(1Y6N8(`D^QQ(+\`5;GD@!FY!`"=X]#Q
M*``$[)<`.@56PMI:@GF9N8(`%KD(`!"YZ&`-N0@`&>QC(+\`5>S1.[\E6>N8
M``(`#.R8`"$>5KF"`#GL@2"_`%6YY'`3N00`/>/0\3``!.PX`#H%5L+:6H)Y
MF;F"`!:Y"``0N>A@#;D(`!/L:2"_`%7LT3N_)5GK-P`"``SL-P`A'E:Y@@"3
M['$@OP!5N>2`&;D$`)WCT/$X``3LEP`Z!5;"VEJ">9FY@@`6N0@`$+GH8`VY
M"``9[&,@OP!5[-$[OR59ZY@``@`,[)@`(1Y6N8(`.>R!(+\`5;GD<!.Y!``]
MX]#Q0``$[#@`.@56N8(`%KD(`!"Y"``3ZS<``@`,[#<`(1Y6XW#Q2``$PMI:
M@GF9N>A@#>QI(+\`5<)Z6H)YF;F"`).Y@`"8N8(`EKD(`)"YZ&`'ZV@``@`,
M[&@`(1Y6XX#Q4``$[',@OP!5PHINV>NAN8(`-NS1.[\E6>S1(#H%5L`:````
M`+F``#&Y@@`WN0@`,.,`\5@`!+D(`)VY"`!X[-D[OR59ZX$``@`,[-D@.@56
M[($`(1Y6N0@`/>P3.[\E6>P3(#H%5KGG@-;""F[9ZZ&Y@@#9N1H`!KD:`'VY
M"`!Q[!<[OR59[!<@.@56L\$`(>S9(K\^6>,0\6``!.S9`B$>5KD$`)"YY]!H
ML\T``KF"`&.Y&@"6[&,BOSY9[&,"(1Y6N>=@/;F"`#>Y"`"0PAINV>NAN1H`
M&.R).[\E6;D:`!/LB2`Z!5:SP0`(L\T`,..`\6@`!+D(`!/L,3N_)5GL,2`Z
M!5:SP0`#XS#Q<``$L\T``,**;MGKH<(Z;MGKH;D:`(VY&@`V[-<BOSY9[-<"
M(1Y6N>?0=KF"`'FY&@"'N0@`@.QH.[\E6>QH(#H%5NQY(K\^6;/!``;L>0(A
M'E;L82*_/EFYYW"=[&$"(1Y6N8(`D;/-`!"Y&@`YXY#Q>``$N0@`,<*:;MGK
MH;GG8!>Y@@`8N1H`G;D:`)'C$/&```3LTSN_)5GLTR`Z!5;"&F[9ZZ&Y"`"=
MN1H`%^S9.[\E6>QX(K\^6>S9(#H%5NQX`B$>5N.`\8@`!+/!``VSS0``N>=P
MUL**;MGKH;F"`-.Y&@"&N1H`'>QC(K\^6;D(`!#L8P(A'E;L,3N_)5GL,2`Z
M!5:SP0`#XS#QD``$L\T``+GG8->Y@@#9PCINV>NAN1H`C;D:`#>Y"`"`['DB
MOSY9[-@[OR59['D"(1Y6[-@@.@56XY#QF``$L\$`#;/-``"YYW#6PIINV>NA
MN8(`T;D:`):Y&@`][&$BOSY9N0@`,.QA`B$>5NP3.[\E6>P3(#H%5K/!``'C
M$/&@``2SS0``N>=@U[F"`-C"&F[9ZZ&Y&@"=N1H`%[D(`)#L>"*_/EGLV3N_
M)5GL>`(A'E;LV2`Z!5;C@/&H``2SP0`-L\T``+GG<-;"BF[9ZZ&Y@@#3N1H`
MAKD:`!WL8R*_/EFY"``0[&,"(1Y6[#$[OR59[#$@.@56L\$``[/-``"YYV#7
MXS#QL``$N8(`V;D:`(VY"`"`[-@[OR59[-@@.@56L\$`#;/-``#".F[9ZZ&Y
M&@`W['DBOSY9['D"(1Y6XY#QN``$N>=PUKF"`-&Y&@`][-$BOSY9N0@`,.S1
M`B$>5NP3.[\E6>P3(#H%5K/!``&SS0``PIINV>NAN1H`EKGGT&>Y@@!HN1H`
MEKD(`)#L:3N_)5GL:2`Z!5;C$/'```2SP0`&XV#QR``$L\T``,(:;MGKH<)J
M;MGKH;D:`!>Y&@!M['@BOSY9['@"(1Y6N>=PC>S3(K\^6;F"`(/LTP(A'E:Y
M&@`8N0@`$.PQ.[\E6>PQ(#H%5K/!``/C,/'0``2SS0``N>?0A\(Z;MGKH;F"
M`(FY&@`WN1H`:+D(`&#L=CN_)5GL=B`Z!5:SP0`'L\T``.R)(K\^6>-P\=@`
M!.R)`B$>5KGG@)VY@@"1N1H`.>R1(K\^6;D(`##LD0(A'E;L$SN_)5GL$R`Z
M!5;">F[9ZZ&SP0`!N1H`?>,0\>``!+GGD-BY@@#6L\T``+D:`'WLUB*_/EGL
MU@(A'E:YY]!IN8(`8\(:;MGKH;D:`!BY&@`6[&,BOSY9[&,"(1Y6XS#QZ``$
MN0@`<.R'(+\`5>P'.[\E6>P(`#H%5L(Z;MGKH;D(`!"Y&@`YN>=@#;F"``>Y
M&@`PN00`D^,P\?``!.QQ(+\`5>P1.[\E6>P7`#H%5L(ZCQN\W+D(`)&Y&@`]
MZQ@``@`,L\$``^P8`"$>5K/-``#LT2"_`%6YY-"&N>80-KF``#>Y@0`X[(D@
MOP!5[)D[OR59[)@`.@56N0@`,.,`\?@`!+D(`#GKEP`"``SLEP`A'E:YY-!Y
MN8$`&;F``!BY@0`7XW#R```$P@J/&[S<N1H`!L)ZCQN\W+D(`!"YZ-`'[&,@
MOP!5[#,[OR59[#8`.@56N0@`,>L8``(`#.P8`"$>5NS1(+\`5;GF$'FYY-")
MN8``=KF!`'BY"`!PXP#R"``$[(,@OP!5P@J/&[S<N1H`">N6``(`#.R6`"$>
M5KGDT&FY@0`9N8``&+F!`!;C8/(0``2Y"``0PFJ/&[S<N>C0!NPS.[\E6>PX
M`#H%5KD(`#?L<R"_`%7L,SN_)5GL-P`Z!5:Y"``QZQ@``@`,[!@`(1Y6[-$@
MOP!5N>80:;GDT(FY@`!GN8$`:+D(`&#C`/(8``3L@R"_`%7""H\;O-RY&@`)
MZY<``@`,[)<`(1Y6N>30>;F!`!FY@``8N8$`%^-P\B``!+D(`!#">H\;O-SL
M,SN_)5FYZ-`'[#@`.@56N0@`-NQC(+\`5>PS.[\E6>PV`#H%5KD(`#'K&``"
M``SL&``A'E;LT2"_`%6YYA")N>30>;F``(:Y@0"'N0@`@.QS(+\`5>,`\B@`
M!.PS.[\E6>PW`#H%5KD(`#CKA@`"``SLA@`A'E:YY-!HN8$`&+F``!>Y@0`6
MXV#R,``$P@J/&[S<N1H`"<)JCQN\W+D(`!"YZ-`&[),@OP!5[#,[OR59[#D`
M.@56N0@`,>L7``(`#.P7`"$>5NS1(+\`5;GF$&BYY-!XN8``:;F!`&>Y"`!@
MXP#R.``$[',@OP!5P@J/&[S<N1H`".N)``(`#.R)`"$>5KGF@)&YY-`8N8``
ME[F!`)'C$/)```2Y"`"0PAJ/&[S<N0@`';/!``&SS0``[#,[OR59[#<`.@56
MN0@`-NQC(+\`5>PS.[\E6>PV`#H%5NL7``(`#+D(`)/L%P`A'E;LT2"_`%6Y
MYA`XN>30>+F``#:Y@0`WN0@`,.,`\D@`!.QY(+\`5<(*CQN\W+/!``#LF3N_
M)5GLEP`Z!5:Y"``YZY8``@`,[)8`(1Y6N>30";/!`""SS0``N8$`&;D:``BS
MP0``L\T``KF``!>Y@0`0L\T``.QC(+\`5>.`\E``!+D(`!#"BH\;O-RYZ-`(
M[#,[OR59[#8`.@56N0@`,>L7``(`#.P7`"$>5NS1(+\`5;GF$'FYY-")N8``
M=KF!`'BY"`!PXP#R6``$[(,@OP!5[#,[OR59[#@`.@56P@J/&[S<N1H`";GH
M,)?K-@`"``SL-@`A'E:YY-!CN8$`$[F``!BY@0`6XV#R8``$N0@`$,)JCQN\
MW+GHT`;L>2"_`%7LF3N_)5GLEP`Z!5:Y"`"1ZQ@``@`,[!@`(1Y6[-$@OP!5
MN>808[GDT(.Y@`!GN8$`:+D(`&#C`/)H``3LB2"_`%7LF3N_)5GLF``Z!5;"
M"H\;O-RY&@`#N>B0-NN7``(`#.R7`"$>5KGDT'FY@0`9N8``&+F!`!?C</)P
M``2Y"``0PGJ/&[S<N>C0!^QC(+\`5>PS.[\E6>PV`#H%5KD(`#'K&``"``SL
M&``A'E;L<2"_`%6YYA#9N>1PB;F``-:Y@0#8N0@`T.,`\G@`!.R#(+\`5<(*
MCQN\W.PS.[\E6;D:``FSP0``[#@`.@56N0@`/>N6``(`#.S3(+\`5>R6`"$>
M5NQC.[\E6;GFD#&YY'`9L\$`(;/-``*Y!``6XV#R@``$N8``.+F!`#"SS0``
M[!T`.@56PFJ/&[S<N0@`,+GH<`:Y"``QZQ@``@`,[!@`(1Y6['$@OP!5N>1P
M:;GF$(FY@`"-N8$`ANQC.[\E6>QC(#H%5KD(`("Y"`"&XV#RB``$ZPT``@`,
MPFJ/&[S<N1H`:;D$`)"SP0`&[)T`(1Y6N>1P:<`Z`````+/-``"Y@0`9N8``
M$[F!`!;C8/*0``2Y"``0PFK*8L'6[-@[OR59N>AP!NS8(#H%5NMS``(`#+D(
M`!WL<P`A'E;L83N_)5FY!``P[&$@.@56X]#RF``$L\$`1K/-``3G0`\/`$2Y
MYW!IN8(`:,+:RF+!UKD:`#:Y&@#9N0@`,+/!`&WL:"*_/EGC`/*@``3L:`(A
M'E:SS0"&[),[OR59[),@.@56N>=@U\(*RF+!UKF"`-&Y&@`'N1H`C;D(`(GL
MF#N_)5GLF"`Z!5;L<2*_/EFSP0`IXY#RJ``$['$"(1Y6N00`$+/-``*YYW#6
MPIK*8L'6N8(`T[D:`):Y&@`=[&,BOSY9N0@`$.QC`B$>5NPQ.[\E6>PQ(#H%
M5K/!``/C,/*P``2SS0``N>=@U[F"`-C".LIBP=:Y&@"=N1H`-[D(`)#L>"*_
M/EGLV3N_)5GL>`(A'E;LV2`Z!5;C@/*X``2SP0`-L\T``+GG<-;"BLIBP=:Y
M@@#1N1H`AKD:`#WL82*_/EFY"``P[&$"(1Y6[!,[OR59[!,@.@56L\$``>,0
M\L``!+/-``"YYV#7N8(`V<(:RF+!UKD:`(VY&@`7N0@`@.QY(K\^6>S8.[\E
M6>QY`B$>5NS8(#H%5N.0\L@`!+/!``VSS0``N>=PUL*:RF+!UKF"`-.Y&@"6
MN1H`'>QC(K\^6;D(`!#L8P(A'E;L,3N_)5GL,2`Z!5:SP0`#XS#RT``$L\T`
M`+GG8->Y@@#8PCK*8L'6N1H`G;D:`#>Y"`"0['@BOSY9[-D[OR59['@"(1Y6
M[-D@.@56XX#RV``$L\$`#;/-``"YYW#6PHK*8L'6N8(`T;D:`(:Y&@`][&$B
MOSY9N0@`,.QA`B$>5NP3.[\E6>P3(#H%5K/!``'C$/+@``2SS0``N>=@U[F"
M`-G"&LIBP=:Y&@"-N1H`%[D(`(#L>2*_/EGLV#N_)5GL>0(A'E;LV"`Z!5;C
MD/+H``2SP0`-L\T``+GG<-;"FLIBP=:Y@@#3N1H`EKD:`!WL8R*_/EFY"``0
M[&,"(1Y6[#$[OR59[#$@.@56L\$``^,P\O``!+/-``"YYV#7N8(`V,(ZRF+!
MUKD:`)VY&@`WN0@`D.QX(K\^6>S9.[\E6>QX`B$>5NS9(#H%5N.`\O@`!+/!
M``VSS0``N>=PUL**RF+!UKF"`-&Y&@"&N1H`/>QA(K\^6;D(`##L80(A'E;L
M$SN_)5GL$R`Z!5:SP0`!XQ#S```$L\T``+GG8->Y@@#9PAK*8L'6N1H`C;D:
M`!>Y"`"`['DBOSY9[-@[OR59['D"(1Y6[-@@.@56XY#S"``$L\$`#;/-``"Y
MYW#6PIK*8L'6N8(`T[D:`):Y&@`=[&,BOSY9N0@`$.QC`B$>5NPQ.[\E6>PQ
M(#H%5K/!``/C,/,0``2SS0``N>=@U\(ZRF+!UKF"`-BY&@`WN1H`G;D(`)#L
M>3N_)5GL>2`Z!5:SP0`'XW#S&``$L\T``.S8(K\^6<)ZRF+!UNS8`B$>5KD:
M`':YY]"&[&$BOSY9N8(`@>QA`B$>5KD:`#BY"``P[!,[OR59[!,@.@56N>=@
MC;/!``&Y@@")XQ#S(``$N1H`>.R)(K\^6>R)`B$>5KGG@):Y@@"3L\T``,(:
MRF+!UKD:`!VY&@`9[),BOSY9[),"(1Y6XS#S*``$N0@`<,(ZRF+!UNS7(+\`
M5;D(`#3L!SN_)5FY&@`V[`T`.@56N0@`$+GGD`BY!`!`N8(`1[D$`'/L,2"_
M`%6Y&@!T[!$[OR59[!,`.@56N0@`%[D(`#KCD/"@``CG`3```&+K30`"``SG
M`$```&CG`"``,`[L30`A'E:YZ%`4YR&0``!BN00`&.<B0```:.<@(!`P#N,0
M("``",`:`````.,0("``)-4'\S"P**=T``;K;_-H``0'_L#E___Q@0<'!P<'
M!P<'!P<'!^MO\#``)./P_V#_<>PH`%P`?,08``!"=^-P$````J>$`%/C$"``
M`)2Y!`""N00`8[D$`)*5`"``IX0`3NP8``P]?D&0D`'C$)```)25`)``IW3_
M]AN8XZ!P```"IX0`'[D4`)FY!`"WN00`2;D$`#BY!``JP.7___`.["8`"0!^
M01F@`)4]$`"GA``/0;"P"..@L````J=T_^FY!``JZV_PT``$!_ZYZ7`;0:F@
M`>L1``,`"E`08`"Y!``JZV_PT``$!_ZGJ0``N00`*NMO\-``!`?^IY@``*?T
M_[\'!P<'ZZ_P4``DLD\`L./P_LC_<>N[`"``#;)/`+&Y!`"BT@?Q,+`H03#P
MH,#E___Q).PF`"$`?A@26"#PN*<X0`#`*P``\`#L(P`(@':E/Z``[",`$V!V
MN00`*J<Y``+`Y?__\8H0$J<:__^($``?I_0`!*<8``#5!_$PL"BY%``AIW0`
M!NNO\8@`!`?^P.7___##ZW_P.``DX^#P`/!QX_#P`/]QXP#_^``@N2$`_J<D
M__BY!`#^X_#_4/]QXP#PJ``@LD\`@.,0\*@0<>N(`"``#;)/`(&Y!`!RITD`
M`J<Y``#2!Q``@"C`Y?__[O7LDO__`-GL&3"``%7LE`!5`'RY"0"10;#PH,"@
M``!!S>R4`$<`?+D$`#FG20``N00`)\#E___NV;D$`#NY!``GP$$``0`(P.7_
M__#/N10`(NPL`"8'?>,2O_C_<>P;``N@9:?T`!WC$!___W'L&P`80&75!Q``
MH`"G=/_WN0D`&[GHD"'C$/"H$''5!Q``@"BG=``>ZW_PZ!`$!_["E``!``#`
M$?__``#LD?^_8&2G*?__I_3_Z:<;___`(?__``"Y@0`2IQL``:?T_Z7`Y?__
M\"P'!^MO\#``)+)/`*#C\/[`_W'KJ@`@``VR3P"AT@?Q.*`H["@`"0!\N00`
M8I4`(`"G=``+U0?Q.*`HIW0`A^MO\7``!`?^P.7___#FN00`DNPH__(`?+D$
M`"G`Y?__[VSL*`!:`'Q!L"`3E2X@$Z=T``:5`+`!IX3_\)4N(!.GA`!7IQD`
M`.Q&/+\`5:>$`%JG.0`/N0D`-.<#8```-Z<;`!#G```P`(&GA``,YP%@`$`&
MIQL`$.<``#``@:=T__CG0``'`"&YA`!$N2``0T$P,`&YXB`3IR0`->-!3_#_
M<:<Y``#L6SR_`%6GA``RIQD`#[D)`!7G`2`3`#>G.P`0YP``,`"!IX0`*.<#
M(!-`!J?T__:Y!``IP.7__^V]N00`)L#E___N"*?T_X:5+K`!IW3_J94`L`*G
MA/^/I_3_HZ<Y``^G]/^TP.7__^^%IQD`#Z?T_]SG4``'`"&YA`!5N2``44$0
M$`&YXB`QIR3_\>,37_#_<;GX$"2G*@`"N10`(L#E___MJ..P\*``)*<Y``&Y
M!`"RP%```!%0ITG__\#E___P&;D$`"M!,/"HP.7__^YB["@`#?]^6!#PP*<H
M0`#`&P``\`#L$@`/@':Y!``KP.7__^^`N00`*\#E___ONZ?T_SJY!``KP.7_
M__\,I_3_]`<'!P<'!P<'!P<'!P<'ZV_P,``DLD\`H,`0``!`0^NJ`"``#>.P
M$```!+)/`*'$2```0#SC*Z````3C\/]8_W'`4```,4/`,```$0'`Y?__[]GE
M2/"@``#C*Z````3`0```#;#`8```$D?`,```$/VY!`!6P.7__^Y%ZV_PV``$
M!_X'!P<'!P<'!P<'!P?K?_`X`"3C\/``_W'C`/_X`"#C\/]8_W'C`/"@`""R
M3P"PXQ#PH`%QZ[L`(``-LD\`L;D$`(/2!Q``L"A!D/"@N00`HKD$`#FG20__
MP"```!#0P.7__^VO["P`$@!^[!+__P#8&$*Y%``A02+PH)4`(`"G=``B[!8`
M'P!^P!```#_*XQ`0```$N00`2.,AL```!+D$`#K`Y?__[4WC$/"@`7'5!Q``
ML"BG=``IZW_PX`$$!_X80;D4`'2Y!``IN00`1Z<Y`"_`Y?__[87L*/_8`'S`
M$```/Y_C$!````2Y!`!7XR&P```$N00`2;D$`#K`Y?__[B"G]/_3P.7__^YK
MZV_P,``DN00`[[)/`(#C\/]`_W&GZ__X8(#@`.N(`"``#;)/`(&Y!`"RN00`
MHY4],`#2!_"P@"BG=``$0:`P`:<9``#L.CR_`%6GA`!YIRD`#[D)`"/G`J``
M`#>G&P`0YP``,`"!IX0`#.<!H`!`!J<;`!#G```P`(&G=/_XYS``!P`AN80`
M,[D@`#)!("`!N>(@$J<D`%3C$3_P_W%!,/"LXQ#PH``DN00`*\#E___\FKD$
M`#+L*`!+`'RG&0``[$(\OP!5IX0`/Z<I``^Y"0`DYP(P```WIQL`$.<``#``
M@:>$``SG`3``0`:G&P`0YP``,`"!IW3_^.=```<`(;F$`$2Y(`!"02`@`;GB
M(!*G)``:XR#PH``$XQ%/\/]Q["$!!,!EXY#PK``4Q'@``#[:ZYD``P`-I_0`
M5Z<I``^G]/^5IRD`#Z?T_\_$>```/LKCD'````3C$)````*GA`#<N00`&:=H
M```8)J=J``%!$!`(XS`0```"IW3_^*<J``.Y%``BZR(``P`-P!```#\JXQ`0
M```2IX0`FKD$`#*Y!``IP.7__^S&XR!P```DL\$`@NPH`'T`?+D4`);KF0`#
M``VSS0`84&#PK.S6``$`V+D4`-WKW0`#``U!'1``Y4@0````XR"P``"4N00`
M&Y4`L`"G=``-I_0`BT$0$`'C(!```)25`!``IX0`!>PF__<]?KD)`!NY%``1
MXR#PH``$N00`:4$B$`+C8'````C`Y?__ZY#C(&```"3L*``Y`'SC('````3C
M$+```)#C.2````1!L+`!0A`P`!A![!8`$`!\I_0`,.,0L```D$&PL`%"$"`!
M&$'L&``F`'Q"0/"@N00`(Y4]\*!!,#`!IW3_[9(](`"G&0``XS&@``"00C$@
M`:<;``'L-O_Y`'S5!_"P@"BG=``W:(#PN.MO\/``!`?^N00`(Z?T_^7`$```
M/HKE3!````'`Y?__ZSRY!`#2L\$`@NPH_^0`?+D$`#FY%`"6ZYD``P`-N00`
M2<#E___KJ>/0<```)*?T_UVG&0``I_3_A:<I`!"G:```I_3_-\#E___LUZ<9
M``#C(:```)!"(3``IQL``>PF__D`?*?T_[<'!P<'!P<'!P<'!P>R3P`@P!``
M`#W>ZR(`(``-XQ`0```$LD\`(<1(```]U^,A(```!,!0```NX<`P```.G\#T
M___M=P<'!P<'!P<'ZV_P,``DX_#P`/]QXP#_^``@X_#P`/]QXP#_^``@X_#_
M2/]QXP#PL``@LD\`D.,0\+`"<>N9`"``#;)/`)'CL/"O`7'2!Q``D"C`Y?__
M[$O`$```#I3C$/"@`"2Y!`!BITD0`:<Y``&Y!``KP%````Z`08#PKL#E___M
M);D$`"NY!``XITD0`,#E___K3.PD`"\`?KD$`+*G*@`!N10`(L#E___JD+D$
M`*+L*``A`'RY%`"[N00`.+D$`$O`Y?__[5)!&Z``D@`0`.,0\+`"<=4'$`"0
M**=T``BY!``JZV_PZ`($!_[`Y?__["VGJ0``I_3_[0<'!P<'!P<'!P<'!\#T
M____@`<'!P<'!P<'!P?K;_`P`"3C\/``_W'C`/_X`"#C\/ZP_W'C`/%(`""R
M3P#0XQ#Q2`%QZ]T`(``-LD\`T;D$`*+2!Q``T"BY!`"3P"````X703#PM,#E
M___Z>Z<Y`"^Y!`"RN00`*L#E___K^NPH`!D`?,`@```."+D$`#K`Y?___7>Y
M!``JXQ#Q2`%QU0<0`-`HIW0!=NMO\8`!!`?^N00`*<#E___K#,`P```-],#E
M___J5KD$`&+L*/_=`'SLBCR_`%5!D/%(07#PN)4`8`"GA`"8[+@`#P!\IP@`
M`+D$`!:Y!``KLET`$J<4__ZGA`!XIQD``.PV/+\`5:>$`0BG*0`/N0D`(^<"
M8```-Z<;`!#G```P`(&GA``,YP%@`$`&IQL`$.<``#``@:=T__CG,``'`"&Y
MA``SN2``,D$@(`&YXB`2IR0`X^-!/_#_<>,4;___<;GI8#'L80!?H&65+Q``
MIW0`V)(`$`#C$!___W&G-__WIQD``.PV/+\`5:>$`">G*0`/N0D`(^<"8```
M-Z<;`!#G```P`(&GA``,YP%@`$`&IQL`$.<``#``@:=T__CG,``'`"&YA``S
MN2``,D$@(`&YXB`2I\0`T:<I``^G]/_GE0"P`:=T`!K`,```#5FG*0``P.7_
M_^FYN00`8NPH_T``?)4`8`"G=/]L[+@`!P!\E2ZP`*>$_^:G20`!P&````TR
MIQD``.R(`'0`?*<I``^Y"0`HYP*@```WIQL`$.<``#``@:>$``SG`:``0`:G
M&P`0YP``,`"!IW3_^.<P``<`(;F$`#.Y(``R02`@`;GB(!*G)`!.XQ$_\/]Q
MIRD/_T$10`'L$O[\(&7CH/"H`"3`$```#0;C$/"@`"2G.0`!N00`*<!0```-
M9J=)$`#`Y?__ZXNY!``WN00`*<#E___IU.PF_Y,`?E@0\-"E+X``P!L``/``
M[!+_B6!VN00`*:<Y``'`Y?__ZV#L)O]_`'ZY!``YP"````S,P.7___P]N00`
M*<#E___IX*?T_L.G*0`/I_3_FZ<I``^G]/\&IQD``.PV/+\`5:>$`"RG*0`/
MN0D`(^<"8```-Z<;`!#G```P`(&GA``,YP%@`$`&IQL`$.<``#``@:=T__CG
M,``'`"&YA``SN2``,D$@(`&YXB`2IR0`!^-!/_#_<:?T_U.G*0`/I_3_XL#E
M___J7@<'!P<'!^N_\%@`)*<Y`"_C\/]@_W&Y!`"RP.7__^KN["@`!0!\0;`@
M`;D$`"OKO_#X``3`]/__Z8$'!P<'!P<'!P<'!P?KG_!(`"3C\/``_W'C`/_X
M`"#C\/]8_W'C`/"@`""R3P"@XQ#PH`%QZZH`(``-LD\`H=('$`"@*.PH`'X`
M?+D$`#*5`"``IX0`=Z<9``#L0CR_`%6GA`!LIRD`#[D)`"3G`C```#>G&P`0
MYP``,`"!IX0`#.<!,`!`!J<;`!#G```P`(&G=/_XYT``!P`AN80`1+D@`$)!
M("`!N>(@$J<D`$?CD4_P_W&G&1``[$D``0#9[$$`4B!E0;#PH+D$`"O`Y?__
MZNCC&;___W&YZ;`A[!L`#L!EE2\0`*=T``F2`!``XQ`?__]QIR?_][D$`"NG
M.0`OP.7__^I>["@`'0!\["L`!<!ED@`@`+D$`"O`Y?__Z/'C$/"@`7'5!Q``
MH"BG=``?ZY_P\`$$!_ZG*0`/I_3_HN,0\*`!<=4'$`"@**=T``_`(```"[3K
MG_#P`03`]/__Z-"G*0``I_3_W<#E___IB0<'!P<'!P<'!P<'!^NO\%``)+)/
M`*#C\/]0_W'KJ@`@``VR3P"A0;#PI-('\*B@*+D$`#O`(```"YG`Y?__]_'L
M*``N`'S$*```.FOC$/"D`!3K$0`#``WC$"````CC(!`(``3C(!```"3L*/_C
M`'SC(!`0``1!$!`(XR`0```D[";_^`!\N00`.\`@```+;L#E___WQNPF_]@`
M?+D$`#O`(```"VC`Y?__][OL*``N`'S$*```.C7C$/"D`!3K$0`#``WC$"``
M``CC(!`(``3C(!```"3L*/_C`'SC(!`0``1!$!`(XR`0```D[";_^`!\N00`
M.\`@```+/<#E___WD.PF_]@`?+D$`#O`(```"S;`Y?__]X7L*``N`'S$*```
M.?_C$/"D`!3K$0`#``WC$"````CC(!`(``3C(!```"3L*/_C`'SC(!`0``1!
M$!`(XR`0```D[";_^`!\N00`.\`@```+"\#E___W6NPF_]@`?+D$`#O`(```
M"P7`Y?__]T_L*``N`'S$*```.<GC$/"D`!3K$0`#``WC$"````CC(!`(``3C
M(!```"3L*/_C`'SC(!`0``1!$!`(XR`0```D[";_^`!\N00`.\`@```*VL#E
M___W).PF_]@`?+D$`#O`(```"M/`Y?__]QGL*``N`'S$*```.9/C$/"D`!3K
M$0`#``WC$"````CC(!`(``3C(!```"3L*/_C`'SC(!`0``1!$!`(XR`0```D
M[";_^`!\N00`.\`@```*J,#E___V[NPF_]@`?+D$`#O`(```"J7`Y?__]N/L
M*``N`'S$*```.5WC$/"D`!3K$0`#``WC$"````CC(!`(``3C(!```"3L*/_C
M`'SC(!`0``1!$!`(XR`0```D[";_^`!\N00`.\`@```*>L#E___VN.PF_]@`
M?+D$`#O`(```"D?`Y?__]JWL*``N`'S$*```.2?C$/"D`!3K$0`#``WC$"``
M``CC(!`(``3C(!```"3L*/_C`'SC(!`0``1!$!`(XR`0```D[";_^`!\N00`
M.\`@```*',#E___V@NPF_]@`?+D$`#O`(```"C_`Y?__]G?L*``N`'S$*```
M./'C$/"D`!3K$0`#``WC$"````CC(!`(``3C(!```"3L*/_C`'SC(!`0``1!
M$!`(XR`0```D[";_^`!\N00`.\`@```*%,#E___V3.PF_]@`?+D$`#O`(```
M"@[`Y?__]D'L*``N`'S$*```.+OC$/"D`!3K$0`#``WC$"````CC(!`(``3C
M(!```"3L*/_C`'SC(!`0``1!$!`(XR`0```D[";_^`!\N00`.\`@```)X\#E
M___V%NPF_]@`?+D$`#O`(```"=W`Y?__]@OL*``N`'S$*```.(7C$/"D`!3K
M$0`#``WC$"````CC(!`(``3C(!```"3L*/_C`'SC(!`0``1!$!`(XR`0```D
M[";_^`!\N00`.\`@```)LL#E___UX.PF_]@`?+D$`#O`(```"73`Y?__]=7L
M*``N`'S$*```.$_C$/"D`!3K$0`#``WC$"````CC(!`(``3C(!```"3L*/_C
M`'SC(!`0``1!$!`(XR`0```D[";_^`!\N00`.\`@```)2<#E___UJNPF_]@`
M?+D$`#O`(```"7;`Y?__]9^Y!``R["@`"0!\P"````EAP.7___BDN00`.\`@
M```);,#E___UC+D$`#+L*``)`'S`(```"6K`Y?__^)&Y!``[P"````EHP.7_
M__5YN00`,NPH`!H`?,`@```)",#E___X?M4'\*B@**=T`"/`,```"6/`(```
M"1KKK_$```3`]/__^&VY!``[P"````E,P.7___55N00`,NPH_^4`?,`@```)
M$L#E___X6J?T_]S`Y?__YKT'!P<'Z[_P6``DLD\`L./P_U#_<>N[`"``#;)/
M`+%!,/"DT@?PJ+`HP"````CSP.7___4K["@`'`!\OR$@`*>$`!?`)P```#"Y
MA``BN0,`(NPB/[\!6=4'\*BP*+D4`"*G=``*Z[_Q"``$!_ZG*```I_3_\\#E
M___F@`<'!P<'!P<'!P?K[_!P`"3C\/]@_W'`Y?__Y&+`Y?__Y#_L*``&`'SC
M("````3K[_$0``0'_@<'!P?K;_`P`"2R3P"@X_#_0/]QZZH`(``-LD\`H;D$
M`&+2!_"XH"A!,/"TP"````C2P.7___31["@`&@!\N00`LI4`(`"GA``3N00`
M-L#E___D:^PH`!P`?-4'\+B@**=T`&/K;_#P``0'_M4'\+B@**=T`%JY!``V
MP"````BKZV_P\``$P/3___>WIQD``.PV/+\`5:>$`$2G*0`/N0D`(^<"8```
M-Z<;`!#G```P`(&GA``,YP%@`$`&IQL`$.<``#``@:=T__CG,``'`"&YA``S
MN2``,D$@(`&YXB`2IR0`'^-!/_#_<:<I``#L.SR_`%6GA``<IQD`#[D)`!/G
M`;```#>G*P`0YP``,`"!IX0`$N<"L`!`!J?T__:G*0`/I_3_RL#E___ESZ<9
M``^G]/_RYS``!P`AN80`,[D@`#%!$!`!N>(@(:<D__'C$C_P_W%!)!`"P.7_
M_^/VX[#PJ``DP!````?;XQ#PH``DN00`LL!0```(/J=)__^G.0`!P.7__^9A
MU0?PN*`HIW3_S+D$`#O`(```"!WK;_#P``3`]/__]RD'!P<'!P<'!P<'!P?K
M;_`P`"2R3P!PX_#^,/]QZW<`(``-LD\`<<`0```VP]('\<AP*$&0\,RY!``Y
MTD?P\!`0T@_PV!!8T@?PZ!!HXR#PP``DP"````>$P.7___/J["@`"0!\N00`
MLI4`(`"G=`%<P.7__^-&P.7__^,C["@`.`!\XZ`@```"IX0`,J<9``#L.CR_
M`%6GA``GIRD`#[D)`"/G`J```#>G&P`0YP``,`"!IX0`#.<!H`!`!J<;`!#G
M```P`(&G=/_XYS``!P`AN80`,[D@`#)!("`!N>(@$J?$`0JG*0`/I_3_YT&P
M\-CC(+````*GA``5N00`.<#E___SE^PH``<`?)4`(`"G=`"_I[L`".,@L```
M`J=T_^^G*0`-P*````>*P.7__^,YIV@`4[D$`+*Y!`#2N00`*[D4`&;`4```
M!WZG2?__ISD``<#E___EI4&@H`%!L+`"XV"@``"4E0"@`*=T_^E!H/$0P"``
M``=#I_0`":>K``CC(*_X_P*GA``@N00`.<#E___S3[D$`++L*/_R`'R5`"``
MIX3_[<#E___SL^PH_^@`?KD$`"O`Y?__X_.Y!`!B["8`'0!\0:#P\.-@H```
M`J>$`!65`&``IX0`T;D$`";`Y?__\Y;L)@"S`'ZGJP`(XV"@```"IW3_[Z<9
M``#L-CR_`%6GA`"WIRD`#[D)`"/G`F```#>G&P`0YP``,`"!IX0`#.<!8`!`
M!J<;`!#G```P`(&G=/_XYS``!P`AN80`,[D@`#)!("`!N>(@$J<D`)+CH3_P
M_W&G*0``[#T\OP!5IX0#`Z<9``^Y"0`3YP'0```WIRL`$.<``#``@:>$`(7G
M`M``0`:G]/_VP.7__^.(N00`HNPH_SX`?*<9``#L,CR_`%6GA`!/IRD`#[D)
M`"/G`J```#>G&P`0YP``,`"!IX0`#.<!H`!`!J<;`!#G```P`(&G=/_XYS``
M!P`AN80`,[D@`#)!("`!N>(@$J<D`"KC(3_P_W'K(@`!``VG*P`!P.7__^),
ME0"@`.-@H```E+D$`+*Y!`#2IW3_$*?T_R?`Y?___9S5!_'(<"BG=``IN00`
M*^MO\@``!,#T___C+Z<I``^G]/^_N00`)J>K``C`Y?__XR2Y!`!B["C_-@!\
MIQD``.PV/+\`5:=T_TVG*0`/I_3_5Z=I``"G]/\^P.7__^/-YS``!P`AN80`
M,[D@`#%!$!`!N>(@(:<D`F7C$C_P_W$:H:>J!`2Y%`"JN00`*L#E___A\^/0
M\+``),`0```&1^,0\*@`),`0```%T^,0\*``)+D$`(*G.0`!P%````8RITG_
M_\#E___D6+D$`"BG.0'`P.7__^-1["8`"_]^P.7__^,;6!`@`.P6`5X1?D'0
M\3BY!``HN00`/<#E___CK1BR["8`#0!^6!#Q4*<H0`#`&P``\`#L$@`F@';C
M(/#```3$&```-*'C4"````3C(!````2Y!`!HP$````89ISD``<#E___C>:>I
M``#5!_'(<"BG=/^$N00`*NMO\@``!`?^6&#Q5,#E___A-^QB_]A@=E@0\5"G
M*`'`P!L```'_[!+_SF!VN00`*L#E___A=;D$`#FY!`"BP"````83P.7___&S
MN00`,NPH`.T`?.,0\,``!.,@$```!,#E___W!;D$`&+L*`#?`'RG&0``[#8\
MOP!5IX0`Y*<I``^Y"0`CYP)@```WIQL`$.<``#``@:>$``SG`6``0`:G&P`0
MYP``,`"!IW3_^.<P``<`(;F$`#.Y(``R02`@`;GB(!*G)`"_XR$_\/]Q["P`
M(`-^N10`$L`P```%R>,1;_S_<:<(``"R70`QIQ3__J=T``_L*`$K!'ZG*O_[
MN10`(D$28`"5+Q``IX0!(+D$`#G`(```!1'`Y?__\4GL*`"S`'SC$"```)3L
M&`"M`'[L&`"J,'[`,```!3?`(```!/S`Y?__]$3`Y?__XGG`$```!?#C(/"H
M`"3C$/"P`"3`$```!,GC$/"@`"2Y!`!HN00`*L!0```%B:=)__^G.0`!P.7_
M_^-,I_0`,L#E___B%U@0(`"G'@`1IW0`,\#E___B3J>Z``&Y%``;XQ#PL``D
MXR#PJ``DP!````6[XQ#PN``DP!````27XQ#PH``DN00`:+D$`"K`4```!5ZG
M2?__ISD``<#E___C&KD$`"JG.0'`P.7__^(3["C_R?]^N00`*,#E___BR[D$
M`#K`(```!&7`Y?__\]NY!``JP.7___O>I_3^Y^,0\,``!.-@$```!*<9``#L
M-CR_`%6G=/\@IRD`#Z?T_RJY%``1XQ#PH``DQ"@``#-;XQ#PP``$XR`@```$
MXU`0```$N00`:,!````$LJ<Y``'`Y?__XC"G]/ZWN00`)J<Y``#`Y?__XI>Y
M!`"2["C_4`!^P.7___$_N00`8NPD_T@`?*=)``#C,&_V_W&Y!``IP.7__^!0
MN00`*:=)``9!,/#2P.7__^)'P!```"0=U040`/#2IW3_+.,P;\[_<;D$`"FG
M20``N00`:,#E___@,[D$`#VY!``IITD`*,#E___B*L`0```%$>/0\*@`).,0
M\+``))(`\6#`$````^CC$/"@`"2Y!``JP%````2BITG__Z<Y``'`Y?__XFVG
M]/]=XQ#PP``$XQ`0"``"IX3^W*<I``#L03R_`%6GA``]ISD`#[D)`#3G`Q``
M`#>G*P`0YP``,`"!IX0`#.<"$`!`!J<K`!#G```P`(&G=/_XYT``!P`AN80`
M1+D@`$-!,#`!N>(@(Z<D`!CC(D_P_W'L+/ZK`WWC,A_\_W&G"```P"````14
MLET`(Z<4__ZYXH!AI_3^FJ<Y``^G]/_1IQD`#Z?T_0L'!P<'!P<'!P<'!P?K
M?_`X`"2R3P"PP*```#)KZ[L`(``-XQ"@```$LD\`L>/P_U#_<>.1L```!$&`
M\*32!_"HL"C2`)"QD+"Y!``XP"````-OP.7__^^U["@`!P!\E3$@`*>$`-+`
MY?__]Z/C$*````3CD;````2Y!``IIUD``Z=)``'`,```!!K`Y?__W[&Y!`"2
M["@`'P!\XQ`@$``$XW"@```$XS`0```$XR>P```$P$````0$P.7__]^JXQ"0
M$``$XS`0```$D4`P#:=T`+/C<*````2G60`#XR>P```$ITD``<`P```#[<#E
M___?@+D$`)+L*``<`'RY!``XP"````+ZP.7__^];N00`0NPH`($`?.,0D!``
M!.,GL```!.,P$```!,#E___?<N.@H```!*=)``'CFK````3`,````\*Y!``I
MP.7__]ZRP$````/%N00`,KD$`"G`Y?__WUCC&K````2Y!``XD@`0L<`@```"
MO<#E___O(\0K```R*+D$`*+L*``L`'RY!``JISD!P,#E___@3.P2``$`V.P<
M`!8!?^PH`!,1?L08```R#+D$`%+C,!````2Y!`!*P"````.@P.7__^##U0?P
MJ+`HIW0`.>M_\.@`!`?^Q"@``#'SP.7___K<Q"L``#'QN00`HNPF_\P`?,`@
M```#<L#E___@II4`(`&GA/\WI_3_+.,@D!``!,08```QUN,@(```!.,P$```
M!,#E___Q6:?T_W_C)[````3`Y?__X"FG]/])P.7__^`T!P?KG_!(`"2R3P"@
MX_#_4/]QZZH`(``-LD\`H;D$`)+2!_"HH"C`Y?__]>:G.0`ON00`LL#E___@
MM^PH``4`?$&P(`&Y!``KP.7__]]-03#PI+D$`++`(````E/`Y?__[HOL*``3
M`'SC$"```)3L&``-`'[L&``*,'[LF``'`'R5`)``IW0`"]4'\*B@**=T`"#K
MG_#X``0'_KD$`"NG20`$P#````)ZP.7__]ZM[";_[0!^U0?PJ*`HIW0`"KD$
M`"GKG_#X``3`]/__[Z7`Y?__W\H'!P<'!P<'!P<'!P<'!^O?\&@`),#0```A
MU>/P_V#_<:<I`(#`Y?__W?7G`-`@,`;E2"`P``#E3"!X``#G`"``,`[G`-`0
M,`;G`"`0,`[G`-``,`;G`"`@,`[KW_$(``0'_@<'!P<'!P<'!P<'!^MO\#``
M).-0("@`!+D$`)+K%``#``VY"``5["$@OP!5N00`A./P_V#_<>-`D#``!+D$
M`+.Y,0!1I\0`!*=+``'K&``=``RY"``4YP(0``!B07"0..<`D"@P#N,@D'@`
M$J=T`#SLC`!D/W[L:/_``-B(8``&[!8``0#8[!$?N099[*'_P`#90=&P`.NJ
M``8`#*>K``'2/W``L`"Y!``I0;"P0,#E___B%Z>G__:GBO_`B6``!AN&N10`
MB+D$`#VY!``GN00`2,#E___@/5"`D'CK;_#0``0'_J>H`$`;HAFHN00`%[GR
M,*BY&``2N00`(;D4`&JY!``[N00`1L#E___@(A@:6A"0>%`0D'CL%O_B0'ZY
M^:"HN00`*;D(`+:Y%`"*P.7__^'7I_3_GKD$`-NG]/_%!P<'!P<'!P<'!P<'
MZX_P0``DP-```"$=X_#_8/]QXY`P*``$N00`L^.`,#``!.PY.K\]6;D4`!-!
M$;`XDH`0`*<Z``&Y!`"BN10`$T$1L#CL/`!I.'ZG2`!`N?DP).Q#`!"`=J<J
M___K,@`(`-[L-@!Y`'ZY%@`BQB````!]N00`*\#E___AC=<WL#BP.&@`T`#K
M&``8``SG`0```"+K&``0``SG`0`!`"+K&``(``SG`0`"`"+K&0`8``SK*0`0
M``SG"``#`"+G`0`$`"+K&0`(``SG`@`%`"+G`0`&`"+G"0`'`")@`+!PN00`
M*\#E___A5](#H`"P!+D$`"O2`Z`$L`S2`Z`(L!32`Z`,L!S2`Z`0L"3KC_#@
M``3`]/__WNBG2``XN?DP).Q#_[*`=J<J___K,@`(`-[L-@`*`'ZY%@`BQB``
M```:I_3_HM?_$``0`$$0$0"G-O_[I_3_\M?_$``0`$$0$0"G-O_[I_3_@]<`
M$``0`-<`$``0``<'!P<'!P<'!P<'!P<'Q%@``"]TP/3__]Q]!P<'!^MO\#``
M)+D$`!^G^_]@XQ#P```DP,```"Y&!P?C0/$0``3K;_#0``0']`<'```````"
M``$E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS
M.CI005(Z.D)/3U0``"]P<F]C+W-E;&8O97AE```O<')O8R\E:2\E<P!E>&4`
M+@!005)?5$5-4```4$%27U!23T=.04U%```Z`"\`4$523#5,24(``%!%4DQ,
M24(`4$523#5/4%0``%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?
M1$5"54<``%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(``%!!4E]'3$]"
M04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.```Q`$Q$7TQ)0E)!4EE?4$%42`!3
M65-414T``"4P,G@``"5S)7,E<R5S``!P87(M```E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E
M<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@
M<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0051(``!P
M87)L```N<&%R```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P`E<R5S
M=&5M<"TE=2TE=25S```8`'!E<FP``#``4$%2.CI086-K97(Z.E9%4E-)3TX`
M`#$N,#4X`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*```M90``+2T``&5V86P@)V5X96,@+W5S<B]B:6XO
M<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N
M9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'
M24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'
M24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?
M<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P
M.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R
M7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J
M(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@
M*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.
M3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@
M*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B
M=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY
M("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R
M;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@
M+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO
M9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U
M:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I
M<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@
M(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@
M+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P
M87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G
M*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M
M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D
M:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I
M;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*
M>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E
M;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS
M;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN
M+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD
M(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD
M*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F
M;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z
M.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D
M7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H
M)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I
M+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@
M.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M
M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<
M)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A
M<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C
M86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L
M("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O
M;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S
M(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC
M7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\
M(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-
M04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U
M=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L
M96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B
M7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B
M7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA
M<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD
M72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L
M(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F
M9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S
M=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?
M<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?
M;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0[
M"G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%
M(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N
M<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F
M=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968[
M"FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N
M*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E
M>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`]
M(%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E
M('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC
M<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI
M<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L
M($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U
M<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO
M9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE
M=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N
M9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE
M.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F
M?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@
M)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O
M+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@
M)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A
M<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL
M($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z
M.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U
M:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F
M:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M
M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE
M;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O
M.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H
M)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@
M869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S
M="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@
M("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@
M*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@
M)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E
M(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'
M5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T
M7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@
M("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI
M.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF
M="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]
M"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN
M8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P
M:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`
M861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U
M<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R
M9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L
M<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H
M)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@
M)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N
M("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I
M;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA
M;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?
M8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@
M=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!
M4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]
M"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H
M:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N
M(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P
M87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I
M"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET[
M"GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@
M/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ
M7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>
M("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R
M96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@
M)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL
M97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E
M4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ
M1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A
M=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(
M+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,
M15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,
M15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R
M(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D
M97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE
M*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@
M0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@
M)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!]
M(&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)
M3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,[
M"B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE
M8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF
M:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_
M"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL
M97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]
M("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H
M0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]
M?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@
M/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R
M968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ
M<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=
M.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I
M"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M
M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA
M<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B
M1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H
M(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N
M="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N
M=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T
M;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*
M?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]
M*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I
M;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W
M*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K
M("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*
M)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N
M86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?
M<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE
M7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M
M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E
M="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O
M=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,[
M"E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R
M871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I
M+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV
M93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q
M<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2
M.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]
M("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O
M:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN
M97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@
M/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE
M(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?
M(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K
M:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S
M(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I
M;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M
M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z
M:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T
M7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2
M.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!
M4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO
M9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@
M72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A
M=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64[
M"FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE
M.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0
M871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T
M:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO
M9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U
M:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S
M.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E
M<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R
M97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E
M.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.
M86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E
M(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS
M=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@
M)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1?
M?2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL
M"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA
M;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@
M:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA
M;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I
M9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L
M<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]
M('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]
M*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@
M)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P
M87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM
M("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY
M("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@
M*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@
M)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H
M95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S
M:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U
M9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H
M95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T
M;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*
M?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M
M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P
M87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T
M96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@
M)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*
M)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP
M;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D
M("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN
M:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?
M<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD
M("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@
M)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N
M9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P
M<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L
M("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%
M?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII
M9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M
M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D
M9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@
M>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D
M14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\[
M"B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES
M>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N
M86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD
M<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G
M;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N
M86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z
M.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ
M1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W
M9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I
M+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.
M251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM0
M05)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@
M0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[
M(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'
M("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@
M:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM0
M05)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O
M=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D
M;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@
M:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E
M9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X
M<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C
M:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@
M4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O
M<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L
M('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R
M>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z
M.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z
M.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?
M7PH`55-%4@``55-%4DY!344``%1%35!$25(`5$U0`"]T;7````````##TN'P
M````````````````F+K<_@`````0,E1V`````&=%(P$`````[\VKB0``````
M````<&5R;'AS:2YC``!#04-(10```````````1L#.P```.0````;__]]P```
M!A3__X`````!`/__@3````$P__^8D````7#__YEP```!T/__F@````(`__^;
M,````D3__YTP```"@/__G;````*\__^>L````OS__Z(````#0/__HD````-4
M__^C0````YC__Z-0```#K/__IM````/L__^G$```!!C__ZB````$8/__KA``
M``24__^ND```!,3__Z[````$Y/__L'````5$__^XX```!93__[L@```%T/__
MO`````94__^\8```!GC__[V@```&M/__OR````;P`````````!0``````7I2
M``%X#@$;#`^@`0<.`````!0````<__]^^````$(``````````````!0`````
M`7I2``%X#@$;#`^@`0```````#P````<__]_^```%U0`1H8.APV(#(D+B@J+
M"8P(C0>.!H\%2@[8!P,7/`K/SLW,R\K)R,?&#J`!0@L```````!<````7/__
MEQ@```#<`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.P`("F`K/SLW,R\K)R,?&
M#J`!0@M<"L_.S<S+RLG(Q\8.H`%""TX*S\[-S,O*R<C'Q@Z@`4(+```````L
M````O/__EY@```"0`$:*"HL)C`B-!XX&CP5*#M@#`G@*S\[-S,O*#J`!0@L`
M``!`````[/__E_@```$N`$:'#8@,B0N*"HL)C`B-!XX&CP5&#`Z@@018#0]&
M#M""!`+,"L_.S<S+RLG(QPZ@`4(+`````#@```$P__^8Y````?(`1H8.APV(
M#(D+B@J+"8P(C0>.!H\%2@[@`W(*S\[-S,O*R<C'Q@Z@`4(+`````#@```%L
M__^:J````'0`1H8.APV(#(D+B@J+"8P(C0>.!H\%;`[(`@)`S\[-S,O*R<C'
MQ@Z@`0```````#P```&H__^:[````0``1H<-B`R)"XH*BPF,"(T'C@:/!48.
MH"%,#L@B`IH*S\[-S,O*R<C'#J`!0@L```````!````!Z/__FZP```-$`$:&
M#H<-B`R)"XH*BPF,"(T'C@:/!4X.X`)(F!4#`J8*S\[-S,O*R<C'QM@.H`%"
M"P```````!````(L__^>N````#@`````````0````D#__Y[D````]`!&A@Z'
M#8@,B0N*"HL)C`B-!XX&CP5&#J`A3`Z@04P.V$("P`K/SLW,R\K)R,?&#J`!
M0@L````0```"A/__GZ`````&`````````#P```*8__^?G````WH`1H8.APV(
M#(D+B@J+"8P(C0>.!H\%1@Z@(4P.\",">@K/SLW,R\K)R,?&#J`!0@L````H
M```"V/__HMP````T`$J+"8P(C0>.!H\%1@[``E[/SLW,RPZ@`0```````$0`
M``,$__^B\````60`1HD+B@J+"8P(C0>.!H\%1@Z@(4P.R"(#`1(*S\[-S,O*
MR0Z@`4(+9`K/SLW,R\K)#J`!1@L``````#````-,__^D&```!8P`1HH*BPF,
M"(T'C@:/!4H.T`(#!48*S\[-S,O*#J`!1@L````````L```#@/__J70```!V
M`$:+"8P(C0>.!H\%2@[0`@)6"L_.S<S+#J`!0@L````````<```#L/__J<0`
M```L`$:.!H\%1@[``E[/S@Z@`0```%P```/0__^IU````:0`1H8.APV(#(D+
MB@J+"8P(C0>.!H\%2@[@`@)6"L_.S<S+RLG(Q\8.H`%""UH*S\[-S,O*R<C'
MQ@Z@`48+`P$6S\[-S,O*R<C'Q@Z@`0```````$P```0P__^K)```"&0`1H8.
MAPV(#(D+B@J+"8P(C0>.!H\%2@[P!`,#(@K/SLW,R\K)R,?&#J`!1@L#`40*
MS\[-S,O*R<C'Q@Z@`4(+````.```!(#__[-$```"/@!&APV(#(D+B@J+"8P(
MC0>.!H\%8`[0`@,!J@K/SLW,R\K)R,<.H`%""P``````0```!+S__[5(````
MT@!&B0N*"HL)C`B-!XX&CP5*#M`"`H8*S\[-S,O*R0Z@`4(+;@K/SLW,R\K)
M#J`!1@L````````\```%`/__=Z0```(Z`$:&#H<-B`R)"XH*BPF,"(T'C@:/
M!4H.Z`(#`9(*S\[-S,O*R<C'Q@Z@`4(+````````(```!4#__[6D````5`!&
MC0>.!H\%3`[``@)`S\[-#J`!````.```!63__[7@```!-`!,A@Z'#8@,B0N*
M"HL)C`B-!XX&CP5>#L`"`JP*S\[-S,O*R<C'Q@Z@`4(+````.```!:#__[;D
M```!<@!&B`R)"XH*BPF,"(T'C@:/!4P.P`("_@K/SLW,R\K)R`Z@`48+````
M````````$```!=S__[@H````#```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(R`````````BT``````````!`````````K\``````````0``
M``````+/``````````P````````8P``````````-````````83``````````
M&0```````+O``````````!L`````````"``````````:````````N\@`````
M````'``````````(`````&___O4````````"D``````````%````````"_``
M````````!@````````-H``````````H````````$-P`````````+````````
M`!@`````````%0````````````````````,```````"]T``````````"````
M````!/@`````````%``````````'`````````!<````````3R``````````'
M````````$4``````````"`````````*(``````````D`````````&```````
M```>``````````@`````;___^P`````(```!`````&____X````````0X```
M``!O____``````````$`````;___\````````!`H`````&____D`````````
M$```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````N]``
M````````````````````````````&2X````````93@```````!EN````````
M&8X````````9K@```````!G.````````&>X````````:#@```````!HN````
M````&DX````````:;@```````!J.````````&JX````````:S@```````!KN
M````````&PX````````;+@```````!M.````````&VX````````;C@``````
M`!NN````````&\X````````;[@```````!P.````````'"X````````<3@``
M`````!QN````````'(X````````<K@```````!S.````````'.X````````=
M#@```````!TN````````'4X````````=;@```````!V.````````':X`````
M```=S@```````!WN````````'@X````````>+@```````!Y.````````'FX`
M```````>C@```````!ZN````````'LX````````>[@```````!\.````````
M'RX````````?3@```````!]N````````'XX````````?K@``````````````
M`````````````````````````%K@````````````````````````````````
M``````````````````````````````````````````````````#`@```````
M````````````'\```````````````````,`("E!!4BYP;0H`````````````
M`````*&J````````8;P``````````````````&)<````````8F````````"A
MG@```````&'"````````H:8``````````````````*&.````````H90`````
M`````````````&0>1T-#.B`H56)U;G1U(#$R+C,N,"TS=6)U;G1U,2D@,3(N
M,RXP```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO
M=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R
M<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET
M`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`
M+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N
M8G-S`"YC;VUM96YT````````````````````````````````````````````
M````````````````````````````````````````````````"P````$`````
M`````@````````(X`````````C@`````````#P````````````````````$`
M`````````````!,````'``````````(````````"2`````````)(````````
M`"0````````````````````$```````````````F````!P`````````"````
M`````FP````````";``````````@````````````````````!```````````
M````-&____8``````````@````````*0`````````I``````````V`````4`
M``````````````@``````````````#X````+``````````(````````#:```
M``````-H````````"(@````&`````@`````````(`````````!@```!&````
M`P`````````"````````"_`````````+\`````````0W````````````````
M`````0``````````````3F____\``````````@```````!`H````````$"@`
M````````M@````4```````````````(``````````@```%MO___^````````
M``(````````0X````````!#@`````````&`````&`````0`````````(````
M``````````!J````!``````````"````````$4`````````10`````````*(
M````!0``````````````"``````````8````=`````0`````````0@``````
M`!/(````````$\@````````$^`````4````5``````````@`````````&```
M`'X````!``````````8````````8P````````!C``````````$``````````
M```````````$``````````````!Y`````0`````````&````````&0``````
M```9``````````;`````````````````````!``````````@````A`````$`
M````````!@```````!_`````````'\````````!!<```````````````````
M`!```````````````(H````!``````````8```````!A,````````&$P````
M`````"P````````````````````$``````````````"0`````0`````````"
M````````86````````!A8````````$"@````````````````````"```````
M````````F`````$``````````@```````*(`````````H@``````````Y```
M``````````````````0``````````````*8````!``````````(```````"B
MZ````````*+H````````!B`````````````````````(``````````````"P
M````#@`````````#````````N\````````"KP``````````(````````````
M````````"``````````(````O`````\``````````P```````+O(````````
MJ\@`````````"`````````````````````@`````````"````,@````&````
M``````,```````"[T````````*O0`````````@`````&```````````````(
M`````````!````#1`````0`````````#````````O=````````"MT```````
M``(P````````````````````"``````````(````U@````$``````````P``
M`````,``````````L```````````B`````````````````````@`````````
M`````-P````(``````````,```````#`B````````+"(`````````"@`````
M```````````````(``````````````#A`````0`````````P````````````
M``````"PB``````````E`````````````````````0`````````!`````0``
M``,`````````````````````````````L*T`````````Z@``````````````
-``````$`````````````
